==> mysql-community_8.4.6.orig.tar.gz: mysql-8.4.6/storage/ndb/clusterj/clusterj-test/src/main/java/testsuite/clusterj/ClearSmokeTest.java <==
/*
   Copyright (c) 2024, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package testsuite.clusterj;

/*
  The purpose of the ClearSmokeTest is to ensure that the SessionFactory
  will be closed at the conclusion of the test suite, so that the NDB API
  can shut down cleanly.
*/

public class ClearSmokeTest extends AbstractClusterJTest {

  public void test() {
  }

  public void localSetUp() {
    createSessionFactory();
    session = sessionFactory.getSession();
  }

  @Override
  public void localTearDown() {
    session.close();
    session = null;
    sessionFactory.close();
  }
}

==> mysql-community_9.5.0.orig.tar.gz: mysql-9.5.0/storage/ndb/clusterj/clusterj-test/src/main/java/testsuite/clusterj/ClearSmokeTest.java <==
/*
   Copyright (c) 2024, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package testsuite.clusterj;

/*
  The purpose of the ClearSmokeTest is to ensure that all SessionFactories
  are closed at the conclusion of the test suite, so that the NDB API
  can shut down cleanly.
*/

public class ClearSmokeTest extends AbstractClusterJTest {

  public void test() {
  }

  @Override
  public void localTearDown() {
    if(session != null) {
        session.close();
        session = null;
    }
    closeAllExistingSessionFactories();
  }
}
